@@ -35,10 +35,10 @@
 static char sccsid[] = "@(#)sys_term.c	8.2 (Berkeley) 12/15/93";
 #endif /* not lint */
 
-/* 	$Id: sys_term.c,v 1.10 1997/08/22 10:18:33 martin Exp $	 */
+/* 	$Id: sys_term.c,v 1.10 1997/08/22 10:18:33 martin Exp martin $	 */
 
 #ifndef lint
-static char vcid[] = "$Id: sys_term.c,v 1.10 1997/08/22 10:18:33 martin Exp $";
+static char vcid[] = "$Id: sys_term.c,v 1.10 1997/08/22 10:18:33 martin Exp martin $";
 #endif /* lint */
 
 #include "telnetd.h"
@@ -165,6 +165,19 @@ extern struct sysv sysv;
 #undef TIOCSCTTY
 #endif
 
+#ifdef USE_SSL
+#define DO_SHUTDOWN(x,y) \
+			 if (debug) { \
+			   fprintf(stderr,"Doing SSL_shutdown\n");\
+			   fflush(stderr); \
+			 } \
+			 if (ssl_active_flag) \
+			   SSL_shutdown(ssl_con); \
+			 shutdown((x),(y))
+#else
+#define DO_SHUTDOWN(x,y) shutdown((x),(y))
+#endif
+
 #ifndef	USE_TERMIO
 struct termbuf {
 	struct sgttyb sg;
@@ -1998,21 +2011,26 @@ cleanup(sig)
 	*p = 'p';
 	(void)chmod(line, 0666);
 	(void)chown(line, 0, 0);
-	(void) shutdown(net, 2);
+	DO_SHUTDOWN(net, 2);
 	exit(1);
 # else
 	void rmut();
 
+	if (debug) {
+		fprintf(stderr,"cleanup(%d)\n",sig);
+		fflush(stderr);
+	}
+
 	rmut();
 #ifdef HAVE_VHANGUP
 	vhangup();	/* XXX */
 #endif
-	(void) shutdown(net, 2);
+	DO_SHUTDOWN(net, 2);
 	exit(1);
 # endif
 #else	/* PARENT_DOES_UTMP */
 # ifdef	NEWINIT
-	(void) shutdown(net, 2);
+	DO_SHUTDOWN(net, 2);
 	exit(1);
 # else	/* NEWINIT */
 #  ifdef CRAY
@@ -2057,7 +2075,7 @@ cleanup(sig)
         rmut();
 #  endif
 	close(pty);
-	(void) shutdown(net, 2);
+	DO_SHUTDOWN(net, 2);
 #  ifdef CRAY
 	if (t == 0)
 		cleantmp(&wtmp);
