@@ -35,10 +35,10 @@
 static char sccsid[] = "@(#)utility.c	8.2 (Berkeley) 12/15/93";
 #endif /* not lint */
 
-/* 	$Id: utility.c,v 1.5 1997/08/22 10:21:59 martin Exp $	 */
+/* 	$Id: utility.c,v 1.5 1997/08/22 10:21:59 martin Exp martin $	 */
 
 #ifndef lint
-static char vcid[] = "$Id: utility.c,v 1.5 1997/08/22 10:21:59 martin Exp $";
+static char vcid[] = "$Id: utility.c,v 1.5 1997/08/22 10:21:59 martin Exp martin $";
 #endif /* lint */
 
 #define PRINTOPTIONS
@@ -546,6 +546,23 @@ putf(cp, where)
 			putstr(editedhost);
 			break;
 
+#ifdef USE_SSL
+                case 'V':
+			/* output prog ver and SSLeay ver */
+		        putstr("[SSL 0.10-");
+			putstr(SSLeay_version(SSLEAY_VERSION));
+			putstr("] ");
+		        break;
+#else /* !USE_SSL */
+
+		/* ignore the version token ... so we can have 
+		 * just the one version string which we hack
+		 * here rather than all over the place
+		 */
+                case 'V':
+		        break;
+#endif /* USE_SSL */
+
 		case 'd':
 			(void)time(&t);
 			(void)strftime(db, sizeof(db), fmtstr, localtime(&t));
